// All database related API calls

import { BackendQueryFormat } from '../../querybuilder/model/BackendQueryFormat';
import { useAuthorizationCache, useSessionCache } from '../store';

export const useQueryAPI = () => {
  const cache = useSessionCache();
  const { accessToken } = useAuthorizationCache();
  const domain = import.meta.env.BACKEND_URL;
  const query_url = import.meta.env.BACKEND_QUERY;

  async function execute(query: BackendQueryFormat) {
    const response = await fetch(`${domain}${query_url}/execute`, {
      method: 'POST',
      credentials: 'same-origin',
      headers: new Headers({
        Authorization: 'Bearer ' + accessToken,
      }),
      body: JSON.stringify(query),
    });

    if (!response?.ok) {
      const ret = await response.text();
      console.error(response, ret);
      throw Error(response.statusText);
    }
    const ret = await response.json();
    console.debug('Sent Query EXECUTION', ret);
  }

  async function retrieveCachedQuery(queryID: string) {
    // TODO: check if this method is needed!
    // const response = await fetch(`${domain}/query/retrieve-cached/`, {
    //     method: 'POST',
    //     credentials: 'same-origin',
    //     headers: new Headers({
    //         Authorization:
    //             'Bearer ' + accessToken,
    //     }),
    //     body: JSON.stringify({ queryID })
    // });
    // if (!response?.ok) {
    //     const ret = await response.text();
    //     console.error(response, ret);
    // }
    // // const ret = await response.json();
    // console.log(response);
  }

  return { execute, retrieveCachedQuery };
};
