import { PropsWithChildren, useEffect, useRef } from 'react';
import { Dialog, DialogProps } from '../../components/Dialog';
import React from 'react';
import CloseIcon from '@mui/icons-material/Close';
import { useAppDispatch, useSchemaSettings } from '../../data-access';
import { SchemaSettings, setSchemaSettings } from '../../data-access/store/schemaSlice';
import { FormActions, FormBody, FormCard, FormControl, FormHBar, FormTitle, FormDiv } from '../../components/forms';

export const SchemaDialog = React.forwardRef<HTMLDivElement, DialogProps>((props, ref) => {
  const settings = useSchemaSettings();
  const dispatch = useAppDispatch();
  const [state, setState] = React.useState<SchemaSettings>(settings);

  useEffect(() => {
    setState(settings);
  }, [settings, props.open]);

  function submit() {
    dispatch(setSchemaSettings(state));

    props.onClose();
  }

  return (
    <>
      {props.open && (
        <FormDiv ref={ref}>
          <FormCard>
            <FormBody
              onSubmit={(e) => {
                e.preventDefault();
                submit();
              }}
            >
              <FormTitle title="Quick Settings" onClose={props.onClose} />
              <FormHBar />
              <FormControl>
                <label className="label cursor-pointer w-fit gap-2 px-0 py-1">
                  <input type="checkbox" checked={true} onChange={(e) => {}} className="checkbox checkbox-xs" />
                  <span className="label-text">Points</span>
                </label>
                <label className="label cursor-pointer w-fit gap-2 px-0 py-1">
                  <input type="checkbox" checked={true} onChange={(e) => {}} className="checkbox checkbox-xs" />
                  <span className="label-text">Line</span>
                </label>
                <label className="label cursor-pointer w-fit gap-2 px-0 py-1">
                  <input type="checkbox" checked={true} onChange={(e) => {}} className="checkbox checkbox-xs" />
                  <span className="label-text">Line</span>
                </label>
              </FormControl>
              <FormHBar />
              <FormControl>
                <label className="label">
                  <span className="label-text">Opacity</span>
                </label>
                <input type="range" min={0} max="100" value="40" onChange={(e) => {}} className="range range-sm" />
              </FormControl>
              <FormHBar />
              <FormControl>
                <label className="label">
                  <span className="label-text">Histogram</span>
                </label>
                ...
              </FormControl>
              <FormHBar />
              <FormControl>
                <label className="label">
                  <span className="label-text">Type of Connection</span>
                </label>
                <select
                  className="select select-primary select-sm "
                  value={state.connectionType}
                  onChange={(e) => {
                    setState({ ...state, connectionType: e.target.value as any });
                  }}
                >
                  <option className="option" value="connection">
                    Default
                  </option>
                  <option className="option" value="step">
                    Step
                  </option>
                  <option className="option" value="straight">
                    Straight
                  </option>
                  <option className="option" value="bezier">
                    Bezier
                  </option>
                </select>
              </FormControl>
              <FormHBar />

              <FormActions onClose={props.onClose} />
            </FormBody>
          </FormCard>
        </FormDiv>
      )}
    </>
  );
});
